@@ -62,7 +62,7 @@ function (x, ..., quant = c(0.02,0.98), width = NULL, varwidth = FALSE,
         group = group, names = names)
     if (plot) {
         bxp(z, width, varwidth = varwidth, notch = notch, log = log, 
-            border = border, col = col, pars = pars, outline = outline, 
+            border = border, boxfill = col, pars = pars, outline = outline, 
             horizontal = horizontal, add = add, at = at)
         invisible(z)
     }
